==> NVIDIA_kernel-1.0-2880.tar.gz: NVIDIA_kernel-1.0-2880/nv-ids.h <==


 
 






 
 
 
 


typedef struct _CHIP_INFO_CHAR {
  unsigned long ulDevID;
  char*         psChip;
  char*         psAdapterString;
} CHIP_INFO_CHAR;

static CHIP_INFO_CHAR sChipInfoChar[] = {
   
  { 0x0020,      "RIVA TNT",                  "RIVA TNT"                 },
  { 0x0028,      "RIVA TNT2",                 "RIVA TNT2"                },
  { 0x002C,      "Vanta",                     "Vanta"                    },
  { 0x0029,      "RIVA TNT2 Ultra",           "RIVA TNT2 Ultra"          },
  { 0x002D,      "RIVA TNT2 Model 64",        "RIVA TNT2 Model 64"       },
  { 0x00A0,      "Aladdin TNT2",              "Aladdin TNT2"             },
  { 0x0100,      "GeForce 256",               "GeForce 256"              },
  { 0x0101,      "GeForce DDR",               "GeForce DDR"              },
  { 0x0103,      "Quadro",                    "Quadro"                   },
  { 0x0110,      "GeForce2 MX/MX 400",       "GeForce2 MX/MX 400"      },
  { 0x0111,      "GeForce2 MX 100/200",      "GeForce2 MX 100/200"     },
  { 0x0113,      "Quadro2 MXR/EX/Go",       "Quadro2 MXR/EX/Go"      },
  { 0x01A0,      "GeForce2 Integrated GPU",   "GeForce2 Integrated GPU"  },
  { 0x0150,      "GeForce2 GTS",              "GeForce2 GTS"             },
  { 0x0151,      "GeForce2 Ti",               "GeForce2 Ti"              },
  { 0x0152,      "GeForce2 Ultra",            "GeForce2 Ultra"           },
  { 0x0153,      "Quadro2 Pro",               "Quadro2 Pro"              },
  { 0x0170,      "GeForce4 MX 460",           "GeForce4 MX 460"          },
  { 0x0171,      "GeForce4 MX 440",           "GeForce4 MX 440"          },
  { 0x0172,      "GeForce4 MX 420",           "GeForce4 MX 420"          },
  { 0x0178,      "Quadro4 500XGL",            "Quadro4 500XGL"           },
  { 0x017A,      "Quadro4 200/400NVS",       "Quadro4 200/400NVS"      },
  { 0x017B,      "Quadro4 550XGL",            "Quadro4 550XGL"           },
  { 0x0200,      "GeForce3",                  "GeForce3"                 },
  { 0x0201,      "GeForce3 Ti 200",           "GeForce3 Ti 200"          },
  { 0x0202,      "GeForce3 Ti 500",           "GeForce3 Ti 500"          },
  { 0x0203,      "Quadro DCC",                "Quadro DCC"               },
  { 0x0250,      "GeForce4 Ti 4600",          "GeForce4 Ti 4600"         },
  { 0x0251,      "GeForce4 Ti 4400",          "GeForce4 Ti 4400"         },
  { 0x0253,      "GeForce4 Ti 4200",          "GeForce4 Ti 4200"         },
  { 0x0258,      "Quadro4 900XGL",            "Quadro4 900XGL"           },
  { 0x0259,      "Quadro4 750XGL",            "Quadro4 750XGL"           },
  { 0x025B,      "Quadro4 700XGL",            "Quadro4 700XGL"           },
  { 0x0112,      "GeForce2 Go",               "GeForce2 Go"              },
  { 0x0174,      "GeForce4 440 Go",           "GeForce4 440 Go"          },
  { 0x0175,      "GeForce4 420 Go",           "GeForce4 420 Go"          },
  { 0x0176,      "GeForce4 420 Go 32M",       "GeForce4 420 Go 32M"      },
  { 0x0179,      "GeForce4 440 Go 64M",       "GeForce4 440 Go 64M"      },
  { 0x017C,      "Quadro4 500 GoGL",          "Quadro4 500 GoGL"         }
};

==> NVIDIA_kernel-1.0-2960.tar.gz: NVIDIA_kernel-1.0-2960/nv-ids.h <==


 
 






 
 
 
 


typedef struct _CHIP_INFO_CHAR {
  unsigned long ulDevID;
  char*         psChip;
  char*         psAdapterString;
} CHIP_INFO_CHAR;

static CHIP_INFO_CHAR sChipInfoChar[] = {
   
  { 0x0020,      "RIVA TNT",                  "RIVA TNT"                 },
  { 0x0028,      "RIVA TNT2",                 "RIVA TNT2"                },
  { 0x002C,      "Vanta",                     "Vanta"                    },
  { 0x0029,      "RIVA TNT2 Ultra",           "RIVA TNT2 Ultra"          },
  { 0x002D,      "RIVA TNT2 Model 64",        "RIVA TNT2 Model 64"       },
  { 0x00A0,      "Aladdin TNT2",              "Aladdin TNT2"             },
  { 0x0100,      "GeForce 256",               "GeForce 256"              },
  { 0x0101,      "GeForce DDR",               "GeForce DDR"              },
  { 0x0103,      "Quadro",                    "Quadro"                   },
  { 0x0110,      "GeForce2 MX/MX 400",       "GeForce2 MX/MX 400"      },
  { 0x0111,      "GeForce2 MX 100/200",      "GeForce2 MX 100/200"     },
  { 0x0113,      "Quadro2 MXR/EX/Go",       "Quadro2 MXR/EX/Go"      },
  { 0x01A0,      "GeForce2 Integrated GPU",   "GeForce2 Integrated GPU"  },
  { 0x0150,      "GeForce2 GTS",              "GeForce2 GTS"             },
  { 0x0151,      "GeForce2 Ti",               "GeForce2 Ti"              },
  { 0x0152,      "GeForce2 Ultra",            "GeForce2 Ultra"           },
  { 0x0153,      "Quadro2 Pro",               "Quadro2 Pro"              },
  { 0x0170,      "GeForce4 MX 460",           "GeForce4 MX 460"          },
  { 0x0171,      "GeForce4 MX 440",           "GeForce4 MX 440"          },
  { 0x0172,      "GeForce4 MX 420",           "GeForce4 MX 420"          },
  { 0x0178,      "Quadro4 500/550 XGL",      "Quadro4 500/550 XGL"     },
  { 0x017A,      "Quadro4 200/400 NVS",      "Quadro4 200/400 NVS"     },
  { 0x0200,      "GeForce3",                  "GeForce3"                 },
  { 0x0201,      "GeForce3 Ti 200",           "GeForce3 Ti 200"          },
  { 0x0202,      "GeForce3 Ti 500",           "GeForce3 Ti 500"          },
  { 0x0203,      "Quadro DCC",                "Quadro DCC"               },
  { 0x0250,      "GeForce4 Ti 4600",          "GeForce4 Ti 4600"         },
  { 0x0251,      "GeForce4 Ti 4400",          "GeForce4 Ti 4400"         },
  { 0x0253,      "GeForce4 Ti 4200",          "GeForce4 Ti 4200"         },
  { 0x0258,      "Quadro4 900 XGL",           "Quadro4 900 XGL"          },
  { 0x0259,      "Quadro4 750 XGL",           "Quadro4 750 XGL"          },
  { 0x025B,      "Quadro4 700 XGL",           "Quadro4 700 XGL"          },
  { 0x0112,      "GeForce2 Go",               "GeForce2 Go"              },
  { 0x0174,      "GeForce4 440 Go",           "GeForce4 440 Go"          },
  { 0x0175,      "GeForce4 420 Go",           "GeForce4 420 Go"          },
  { 0x0176,      "GeForce4 420 Go 32M",       "GeForce4 420 Go 32M"      },
  { 0x0179,      "GeForce4 440 Go 64M",       "GeForce4 440 Go 64M"      },
  { 0x017C,      "Quadro4 500 GoGL",          "Quadro4 500 GoGL"         }
};
